#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.4
visibility:           public
id:                   genvalidity-hspec-1.0.0.4-Gq3gUsV6MQI4XzlDVqQ8eK
key:                  genvalidity-hspec-1.0.0.4-Gq3gUsV6MQI4XzlDVqQ8eK
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  a1e234d05bf5e6d09fc222d44ce15164
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/genvalidity-hspec-1.0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/genvalidity-hspec-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/genvalidity-hspec-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.4-Gq3gUsV6MQI4XzlDVqQ8eK
depends:
    QuickCheck-2.15.0.1-Y3YQMP4GBmEag69ihaw37 base-4.18.2.1
    genvalidity-1.1.1.0-EkuKPbnDBiv2J1mbpHdW8j
    genvalidity-property-1.0.0.0-BNJhFB9TnEL7f4NvpygTjD
    hspec-2.11.4-51CvlZUKFvW7JJCx2o2BE
    hspec-core-2.11.4-Azxpk4JJ6Zq7YnrVCmlIlB transformers-0.6.1.0
    validity-0.12.1.0-BA3BxwmQpgpKTymrnvFHCK

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

